@@ -2,7 +2,7 @@
 
   VSEARCH: a versatile open source tool for metagenomics
 
-  Copyright (C) 2014-2018, Torbjorn Rognes, Frederic Mahe and Tomas Flouri
+  Copyright (C) 2014-2019, Torbjorn Rognes, Frederic Mahe and Tomas Flouri
   All rights reserved.
 
   Contact: Torbjorn Rognes <torognes@ifi.uio.no>,
@@ -75,20 +75,6 @@ void fasta_close(fastx_handle h)
   fastx_close(h);
 }
 
-void fasta_truncate_header(fastx_handle h, bool truncateatspace)
-{
-  /* Truncate the zero-terminated header string by inserting a new
-     terminator (zero byte) at the first space/tab character
-     (if truncateatspace) or first linefeed. */
-
-  if (truncateatspace)
-    h->header_buffer.length = strcspn(h->header_buffer.data, " \t\n");
-  else
-    h->header_buffer.length = strcspn(h->header_buffer.data, "\n");
-
-  h->header_buffer.data[h->header_buffer.length] = 0;
-}
-
 void fasta_filter_sequence(fastx_handle h,
                            unsigned int * char_action,
                            const unsigned char * char_mapping)
@@ -123,13 +109,13 @@ void fasta_filter_sequence(fastx_handle h,
           if ((c>=32) && (c<127))
             snprintf(msg,
                      200,
-                     "illegal character '%c' on line %" PRIu64 " in FASTA file",
+                     "Illegal character '%c' in sequence on line %" PRIu64 " of FASTA file",
                      (unsigned char)c,
                      h->lineno);
           else
             snprintf(msg,
                      200,
-                     "illegal unprintable character %#.2x (hexadecimal) on line %" PRIu64 " in FASTA file",
+                     "Illegal unprintable ASCII character no %d in sequence on line %" PRIu64 " of FASTA file",
                      (unsigned char) c,
                      h->lineno);
           fatal(msg);
@@ -241,7 +227,7 @@ bool fasta_next(fastx_handle h,
 
   h->seqno++;
 
-  fasta_truncate_header(h, truncateatspace);
+  fastx_filter_header(h, truncateatspace);
   fasta_filter_sequence(h, char_fasta_action, char_mapping);
 
   return 1;
@@ -249,7 +235,19 @@ bool fasta_next(fastx_handle h,
 
 int64_t fasta_get_abundance(fastx_handle h)
 {
-  return abundance_get(h->header_buffer.data, h->header_buffer.length);
+  // return 1 if not present
+  int64_t size = header_get_size(h->header_buffer.data,
+                                 h->header_buffer.length);
+  if (size > 0)
+    return size;
+  else
+    return 1;
+}
+
+int64_t fasta_get_abundance_and_presence(fastx_handle h)
+{
+  // return 0 if not present
+  return header_get_size(h->header_buffer.data, h->header_buffer.length);
 }
 
 uint64_t fasta_get_position(fastx_handle h)
@@ -332,6 +330,7 @@ void fasta_print_general(FILE * fp,
                          int header_len,
                          int abundance,
                          int ordinal,
+                         double ee,
                          int clustersize,
                          int clusterid,
                          const char * score_name,
@@ -348,10 +347,16 @@ void fasta_print_general(FILE * fp,
     fprint_seq_digest_md5(fp, seq, len);
   else if (opt_relabel && (ordinal > 0))
     fprintf(fp, "%s%d", opt_relabel, ordinal);
-  else if (opt_xsize || (opt_sizeout && abundance > 0))
-    abundance_fprint_header_strip_size(fp, header, header_len);
   else
-    fprintf(fp, "%s", header);
+    {
+      bool xsize = opt_xsize || (opt_sizeout && (abundance > 0));
+      bool xee = opt_xee || ((opt_eeout || opt_fastq_eeout) && (ee >= 0.0));
+      header_fprint_strip_size_ee(fp,
+                                  header,
+                                  header_len,
+                                  xsize,
+                                  xee);
+    }
 
   if (clustersize > 0)
     fprintf(fp, ";seqs=%d", clustersize);
@@ -359,9 +364,12 @@ void fasta_print_general(FILE * fp,
   if (clusterid >= 0)
     fprintf(fp, ";clusterid=%d", clusterid);
 
-  if ((abundance > 0) && opt_sizeout)
+  if (opt_sizeout && (abundance > 0))
     fprintf(fp, ";size=%u", abundance);
 
+  if ((opt_eeout || opt_fastq_eeout) && (ee >= 0.0))
+    fprintf(fp, ";ee=%.4lf", ee);
+
   if (score_name)
     fprintf(fp, ";%s=%.4lf", score_name, score);
 
@@ -387,6 +395,7 @@ void fasta_print_db_relabel(FILE * fp,
                       db_getheaderlen(seqno),
                       db_getabundance(seqno),
                       ordinal,
+                      -1.0,
                       -1, -1,
                       0, 0.0);
 }
@@ -401,6 +410,7 @@ void fasta_print_db(FILE * fp, uint64_t seqno)
                       db_getheaderlen(seqno),
                       db_getabundance(seqno),
                       0,
+                      -1.0,
                       -1, -1,
                       0, 0.0);
 }
