@@ -2,7 +2,7 @@
 
   VSEARCH: a versatile open source tool for metagenomics
 
-  Copyright (C) 2014-2018, Torbjorn Rognes, Frederic Mahe and Tomas Flouri
+  Copyright (C) 2014-2019, Torbjorn Rognes, Frederic Mahe and Tomas Flouri
   All rights reserved.
 
   Contact: Torbjorn Rognes <torognes@ifi.uio.no>,
@@ -76,6 +76,7 @@ char * fasta_get_sequence(fastx_handle h);
 uint64_t fasta_get_header_length(fastx_handle h);
 uint64_t fasta_get_sequence_length(fastx_handle h);
 int64_t fasta_get_abundance(fastx_handle h);
+int64_t fasta_get_abundance_and_presence(fastx_handle h);
 
 /* fasta output */
 
@@ -92,6 +93,7 @@ void fasta_print_general(FILE * fp,
                          int header_len,
                          int abundance,
                          int ordinal,
+                         double ee,
                          int clustersize,
                          int clusterid,
                          const char * score_name,
