@@ -2,7 +2,7 @@
 
   VSEARCH: a versatile open source tool for metagenomics
 
-  Copyright (C) 2014-2018, Torbjorn Rognes, Frederic Mahe and Tomas Flouri
+  Copyright (C) 2014-2019, Torbjorn Rognes, Frederic Mahe and Tomas Flouri
   All rights reserved.
 
   Contact: Torbjorn Rognes <torognes@ifi.uio.no>,
@@ -240,19 +240,44 @@ FILE * fileopenw(char * filename)
 inline int get_qual(char q)
 {
   int qual = q - opt_fastq_ascii;
-  char msg[200];
 
   if (qual < opt_fastq_qmin)
     {
-      snprintf(msg, 200, "FASTQ quality value (%d) below qmin (%" PRId64 ")",
-               qual, opt_fastq_qmin);
-      fatal(msg);
+      fprintf(stderr,
+              "\n\nFatal error: FASTQ quality value (%d) below qmin (%"
+              PRId64 ")\n",
+              qual, opt_fastq_qmin);
+      if (fp_log)
+        {
+          fprintf(stderr,
+                  "\n\nFatal error: FASTQ quality value (%d) below qmin (%"
+                  PRId64 ")\n",
+                  qual, opt_fastq_qmin);
+        }
+      exit(EXIT_FAILURE);
     }
   else if (qual > opt_fastq_qmax)
     {
-      snprintf(msg, 200, "FASTQ quality value (%d) above qmax (%" PRId64 ")",
-               qual, opt_fastq_qmax);
-      fatal(msg);
+      fprintf(stderr,
+              "\n\nFatal error: FASTQ quality value (%d) above qmax (%"
+              PRId64 ")\n",
+              qual, opt_fastq_qmax);
+      fprintf(stderr,
+              "By default, quality values range from 0 to 41.\n"
+              "To allow higher quality values, "
+              "please use the option --fastq_qmax %d\n", qual);
+      if (fp_log)
+        {
+          fprintf(fp_log,
+                  "\n\nFatal error: FASTQ quality value (%d) above qmax (%"
+                  PRId64 ")\n",
+                  qual, opt_fastq_qmax);
+          fprintf(fp_log,
+                  "By default, quality values range from 0 to 41.\n"
+                  "To allow higher quality values, "
+                  "please use the option --fastq_qmax %d\n", qual);
+        }
+      exit(EXIT_FAILURE);
     }
   return qual;
 }
@@ -372,7 +397,6 @@ void keep(merge_data_t * ip)
                           ip->merged_quality,
                           0,
                           merged,
-                          (opt_eeout || opt_fastq_eeout) ? "ee" : 0,
                           ip->ee_merged);
     }
 
@@ -386,10 +410,11 @@ void keep(merge_data_t * ip)
                           strlen(ip->merged_header),
                           0,
                           merged,
+                          ip->ee_merged,
                           -1,
                           -1,
-                          (opt_eeout || opt_fastq_eeout) ? "ee" : 0,
-                          ip->ee_merged);
+                          0,
+                          0.0);
     }
 
   if (opt_eetabbedout)
@@ -476,7 +501,7 @@ void discard(merge_data_t * ip)
                         ip->fwd_quality,
                         0,
                         notmerged,
-                        0, 0.0);
+                        -1.0);
 
   if (opt_fastqout_notmerged_rev)
     fastq_print_general(fp_fastqout_notmerged_rev,
@@ -487,7 +512,7 @@ void discard(merge_data_t * ip)
                         ip->rev_quality,
                         0,
                         notmerged,
-                        0, 0.0);
+                        -1.0);
 
   if (opt_fastaout_notmerged_fwd)
     fasta_print_general(fp_fastaout_notmerged_fwd,
@@ -498,6 +523,7 @@ void discard(merge_data_t * ip)
                         strlen(ip->fwd_header),
                         0,
                         notmerged,
+                        -1.0,
                         -1, -1,
                         0, 0.0);
 
@@ -510,6 +536,7 @@ void discard(merge_data_t * ip)
                         strlen(ip->rev_header),
                         0,
                         notmerged,
+                        -1.0,
                         -1, -1,
                         0, 0.0);
 }
