@@ -2,7 +2,7 @@
 
   VSEARCH: a versatile open source tool for metagenomics
 
-  Copyright (C) 2014-2018, Torbjorn Rognes, Frederic Mahe and Tomas Flouri
+  Copyright (C) 2014-2019, Torbjorn Rognes, Frederic Mahe and Tomas Flouri
   All rights reserved.
 
   Contact: Torbjorn Rognes <torognes@ifi.uio.no>,
@@ -58,6 +58,7 @@
 
 */
 
+#define _GNU_SOURCE 1
 #define __STDC_CONSTANT_MACROS 1
 #define __STDC_FORMAT_MACROS 1
 #define __STDC_LIMIT_MACROS 1
@@ -99,12 +100,7 @@
 #ifdef __x86_64__
 
 #define PROG_CPU "x86_64"
-#ifdef __SSE2__
-#include <emmintrin.h>
-#endif
-#ifdef __SSSE3__
-#include <tmmintrin.h>
-#endif
+#include <x86intrin.h>
 
 #elif __PPC__
 
@@ -132,34 +128,55 @@
 #define PROG_OS "win"
 #include <windows.h>
 #include <psapi.h>
+#include <shlwapi.h>
 #define bswap_16(x) _byteswap_ushort(x)
 #define bswap_32(x) _byteswap_ulong(x)
 #define bswap_64(x) _byteswap_uint64(x)
 
-#else
-
-#ifdef __APPLE__
+#elif __APPLE__
 
 #define PROG_OS "macos"
 #include <sys/sysctl.h>
 #include <libkern/OSByteOrder.h>
+#include <sys/resource.h>
 #define bswap_16(x) OSSwapInt16(x)
 #define bswap_32(x) OSSwapInt32(x)
 #define bswap_64(x) OSSwapInt64(x)
 
-#else
+#elif __linux__
 
-#ifdef __linux__
 #define PROG_OS "linux"
-#else
-#define PROG_OS "unknown"
-#endif
-
 #include <sys/sysinfo.h>
 #include <byteswap.h>
+#include <sys/resource.h>
 
-#endif
+#elif __FreeBSD__
 
+#define PROG_OS "freebsd"
+#include <sys/sysinfo.h>
+#include <sys/resource.h>
+#include <sys/endian.h>
+#define bswap_16(x) bswap16(x)
+#define bswap_32(x) bswap32(x)
+#define bswap_64(x) bswap64(x)
+
+#elif __NetBSD__
+
+#define PROG_OS "netbsd"
+#include <sys/resource.h>
+#include <sys/types.h>
+#include <sys/bswap.h>
+#define bswap_16(x) bswap16(x)
+#define bswap_32(x) bswap32(x)
+#define bswap_64(x) bswap64(x)
+/* Alters behavior, but NetBSD 7 does not have getopt_long_only() */
+#define getopt_long_only getopt_long
+
+#else
+
+#define PROG_OS "unknown"
+#include <sys/sysinfo.h>
+#include <byteswap.h>
 #include <sys/resource.h>
 
 #endif
@@ -189,7 +206,7 @@
 #include "xstring.h"
 #include "align_simd.h"
 #include "maps.h"
-#include "abundance.h"
+#include "attributes.h"
 #include "db.h"
 #include "align.h"
 #include "unique.h"
@@ -217,6 +234,7 @@
 #include "fasta.h"
 #include "fastq.h"
 #include "fastqops.h"
+#include "filter.h"
 #include "dbhash.h"
 #include "searchexact.h"
 #include "mergepairs.h"
@@ -228,6 +246,8 @@
 #include "sintax.h"
 #include "fastqjoin.h"
 #include "sffconvert.h"
+#include "getseq.h"
+#include "cut.h"
 
 /* options */
 
@@ -240,6 +260,7 @@ extern bool opt_fastq_allowmergestagger;
 extern bool opt_fastq_eeout;
 extern bool opt_fastq_nostagger;
 extern bool opt_gzip_decompress;
+extern bool opt_label_substr_match;
 extern bool opt_no_progress;
 extern bool opt_quiet;
 extern bool opt_relabel_keep;
@@ -248,6 +269,7 @@ extern bool opt_relabel_sha1;
 extern bool opt_samheader;
 extern bool opt_sff_clip;
 extern bool opt_sizeorder;
+extern bool opt_xee;
 extern bool opt_xsize;
 extern char * opt_allpairs_global;
 extern char * opt_alnout;
@@ -262,6 +284,8 @@ extern char * opt_cluster_smallmem;
 extern char * opt_cluster_unoise;
 extern char * opt_clusters;
 extern char * opt_consout;
+extern char * opt_cut;
+extern char * opt_cut_pattern;
 extern char * opt_db;
 extern char * opt_dbmatched;
 extern char * opt_dbnotmatched;
@@ -270,8 +294,10 @@ extern char * opt_derep_prefix;
 extern char * opt_eetabbedout;
 extern char * opt_fastaout;
 extern char * opt_fastaout_discarded;
+extern char * opt_fastaout_discarded_rev;
 extern char * opt_fastaout_notmerged_fwd;
 extern char * opt_fastaout_notmerged_rev;
+extern char * opt_fastaout_rev;
 extern char * opt_fastapairs;
 extern char * opt_fastq_chars;
 extern char * opt_fastq_convert;
@@ -283,15 +309,25 @@ extern char * opt_fastq_mergepairs;
 extern char * opt_fastq_stats;
 extern char * opt_fastqout;
 extern char * opt_fastqout_discarded;
+extern char * opt_fastqout_discarded_rev;
+extern char * opt_fastqout_rev;
 extern char * opt_fastqout_notmerged_fwd;
 extern char * opt_fastqout_notmerged_rev;
 extern char * opt_fastx_filter;
+extern char * opt_fastx_getseq;
+extern char * opt_fastx_getseqs;
+extern char * opt_fastx_getsubseq;
 extern char * opt_fastx_mask;
 extern char * opt_fastx_revcomp;
 extern char * opt_fastx_subsample;
 extern char * opt_join_padgap;
 extern char * opt_join_padgapq;
+extern char * opt_label;
 extern char * opt_label_suffix;
+extern char * opt_labels;
+extern char * opt_label_word;
+extern char * opt_label_words;
+extern char * opt_label_field;
 extern char * opt_log;
 extern char * opt_makeudb_usearch;
 extern char * opt_maskfasta;
@@ -300,6 +336,7 @@ extern char * opt_mothur_shared_out;
 extern char * opt_msaout;
 extern char * opt_nonchimeras;
 extern char * opt_notmatched;
+extern char * opt_notmatchedfq;
 extern char * opt_otutabout;
 extern char * opt_output;
 extern char * opt_pattern;
@@ -436,6 +473,8 @@ extern int64_t opt_selfid;
 extern int64_t opt_sizein;
 extern int64_t opt_sizeout;
 extern int64_t opt_strand;
+extern int64_t opt_subseq_start;
+extern int64_t opt_subseq_end;
 extern int64_t opt_threads;
 extern int64_t opt_top_hits_only;
 extern int64_t opt_topn;
